@@ -63,9 +63,9 @@ class logger:
     def debug(self, *items):
         self.log(*items, level='debug')
     
-    def current_time(self, *items):
+    def current_time(self, *items, level='info'):
         coloredlogs.install(level=logging.INFO, logger=self.logger, fmt='%(asctime)s.%(msecs)03d: %(message)s', datefmt='%H:%M:%S') # Add curent time to printed log output format
-        self.log(*items)
+        self.log(*items, level=level)
         coloredlogs.install(level=logging.INFO, logger=self.logger, fmt='%(message)s') # Reset to default log format
 
 class printr:
